import { createContext, useCallback, useContext, useEffect, useState } from "react";
import { isNil } from "../../shared";
import { supportsMatchMedia } from "./useMediaQuery";
import { useDebouncedCallback } from "use-debounce";
/* eslint-disable sort-keys-fix/sort-keys-fix */

import { jsx as _jsx } from "react/jsx-runtime";
export const Breakpoints = {
  xs: "(min-width: 640px)",
  sm: "(min-width: 768px)",
  md: "(min-width: 1024px)",
  lg: "(min-width: 1280px)",
  xl: "(min-width: 1536px)"
};
/* eslint-enable sort-keys-fix/sort-keys-fix */

export const BreakpointContext = /*#__PURE__*/createContext({});
// Reversing breakpoints to resolve from higher to lower.
const ReversedBreakpoints = Object.entries(Breakpoints).reduce((acc, entry) => {
  acc.unshift(entry);
  return acc;
}, []);
export function BreakpointProvider({
  children,
  unsupportedMatchMediaBreakpoint = "lg"
}) {
  // Took from https://github.com/adobe/react-spectrum/blob/main/packages/%40react-spectrum/utils/src/BreakpointProvider.tsx
  const getBreakpointHandler = useCallback(() => {
    if (supportsMatchMedia) {
      const matched = [];

      for (const [key, value] of ReversedBreakpoints) {
        if (window.matchMedia(value).matches) {
          matched.push(key);
        }
      }

      return matched;
    }

    return [unsupportedMatchMediaBreakpoint];
  }, [unsupportedMatchMediaBreakpoint]);
  const [matchedBreakpoints, setMatchedBreakpoints] = useState(getBreakpointHandler);
  const handleResize = useDebouncedCallback(() => {
    setMatchedBreakpoints(getBreakpointHandler());
  }, 50);
  useEffect(() => {
    window.addEventListener("resize", handleResize);
    return () => {
      window.removeEventListener("resize", handleResize);
    };
  }, [handleResize]);
  return /*#__PURE__*/_jsx(BreakpointContext.Provider, {
    value: {
      matchedBreakpoints
    },
    children: children
  });
}
export function useBreakpointContext() {
  return useContext(BreakpointContext);
}
export function useMatchedBreakpoints() {
  const context = useContext(BreakpointContext);
  return !isNil(context) ? context.matchedBreakpoints : [];
}